pub async fn execute(
client: &IronflowClient,
args: &ApiKeyArgs,
json_mode: bool,
) -> Result<()>Expand description
Execute an API key subcommand.
Errors
Returns an error on API failure or when a destructive command is not confirmed.
pub async fn execute(
client: &IronflowClient,
args: &ApiKeyArgs,
json_mode: bool,
) -> Result<()>Execute an API key subcommand.
Returns an error on API failure or when a destructive command is not confirmed.