pub enum OverlapArg {
Allow,
Skip,
}Expand description
--overlap values.
Variants
Allow
Start another run even if one is still active.
Skip
Drop the occurrence while a run of the schedule is still active.