pub fn audit_logs_table(entries: &[AuditLogEntry]) -> TableExpand description
Render a list of audit log entries as a table.
The event payload is omitted: it is arbitrary JSON that would wreck the
table layout. Use --json to get it.
pub fn audit_logs_table(entries: &[AuditLogEntry]) -> TableRender a list of audit log entries as a table.
The event payload is omitted: it is arbitrary JSON that would wreck the
table layout. Use --json to get it.