pub fn run_diff_table(a: &RunDetailResponse, b: &RunDetailResponse) -> TableExpand description
Render a side-by-side comparison of two runs of the same workflow.
pub fn run_diff_table(a: &RunDetailResponse, b: &RunDetailResponse) -> TableRender a side-by-side comparison of two runs of the same workflow.