pub fn execute(client: &IronflowClient, args: &DashboardArgs) -> Result<()>Expand description
Execute the dashboard command.
Constructs the dashboard URL from the client’s base URL and either opens it in the default browser or prints it to stdout.
Errors
Returns an error if the browser cannot be opened.