execute

Function execute 

pub async fn execute(
    client: &IronflowClient,
    args: &SecretArgs,
    json_mode: bool,
) -> Result<()>
Execute a secret subcommand.

Errors

Returns an error on API failure, on an empty value, when a destructive command is not confirmed, or when a rotation left secrets behind because they could not be decrypted.